@@ -2,6 +2,7 @@
 import datetime
 import functools
 import io
+import itertools
 import json
 import os
 import random
@@ -43,11 +44,14 @@ def require_authentication(func):
 
 
 def generate_nav(pages):
+    pages = list(itertools.chain(pages, config.extra_nav_urls))
+    pages.sort(key=lambda i: i.path)
     nav = []
     page_stack = []
     page_name_stack = []
 
     for page in pages:
+        print(page.path, page_name_stack)
         page.subpages = []
         parts = page.path.split('/')
         max_index = 0
@@ -71,7 +75,11 @@ def generate_nav(pages):
             page_name_stack.extend(parts[max_index:])
             assert len(page_name_stack) == len(parts)
             while len(page_stack) < len(parts) - 1:
-                page_stack.append(page_stack[-1])
+                if len(page_stack) >= 1:
+                    page_stack.append(page_stack[-1])
+                else:
+                    # No suitable page found, whatever
+                    page_stack.append(page)
             page_stack.append(page)
 
     nav.sort(key=lambda i: i.sort_order)
@@ -80,6 +88,7 @@ def generate_nav(pages):
 
 @cms.route("editor")
 @cms.route("editor/")
+@require_authentication
 def editor_home():
     nrof_pages = config.db_connection.get_nrof_pages()
     nrof_images = config.db_connection.get_nrof_images()
@@ -305,7 +314,8 @@ def page(path):
     return render_template(
         config.template_name,
         page=page,
-        nav=nav
+        nav=nav,
+        **config.extra_page_content_provider(path)
     )
 
 
@@ -327,6 +337,7 @@ def build_initial_nav():
 def cms_fragment(name):
     return fragments.get_fragment(name).html
 
+
 nav = []
 fragments_map = {}
 
