@@ -8,7 +8,9 @@ def noop_authentication_function(action, parameters) -> typing.Optional[flask.Re
     return None
 
 
-editor_paths = ['editor', 'upload_image', 'delete_image', 'list_images', 'delete_page', 'fragment']
+editor_paths = [
+    'editor', 'upload_image', 'delete_image', 'list_images', 'delete_page', 'fragment',
+    'editor_home']
 viewer_paths = ['page', 'get_image']
 
 db_connection: typing.Optional[db.DatabaseProvider] = None
@@ -38,3 +40,10 @@ markdown_extra_attrs = {
     'div': ['class'],
     'span': ['class']
 }
+
+"""
+Provides extra context for the page template
+"""
+extra_page_content_provider = lambda path: {}
+
+extra_nav_urls: typing.List[dataclasses.ExtraNavUrl] = []
